@@ -13,9 +13,12 @@ import traceback
 from datetime import datetime
 from typing import Any, Dict, List, Optional, Union
 
-logger = logging.getLogger(__name__)
+from mcp.types import ToolAnnotations
 
 from src.core.utils import BaseInstanaClient, register_as_tool, with_header_auth
+from src.prompts import mcp
+
+logger = logging.getLogger(__name__)
 
 # Import the necessary classes from the SDK
 try:
@@ -68,7 +71,10 @@ class ApplicationSettingsMCPTools(BaseInstanaClient):
             traceback.print_exc(file=sys.stderr)
             raise
 
-    @register_as_tool
+    @register_as_tool(
+        title="Get All Applications Configs",
+        annotations=ToolAnnotations(readOnlyHint=True, destructiveHint=False)
+    )
     @with_header_auth(ApplicationSettingsApi)
     async def get_all_applications_configs(self,
                              ctx=None,
@@ -85,24 +91,34 @@ class ApplicationSettingsMCPTools(BaseInstanaClient):
         """
         try:
             debug_print("Fetching all applications and their settings")
-            result = api_client.get_application_configs()
-            # Convert the result to a list of dictionaries
-            if isinstance(result, list):
-                result_dict = [item.to_dict() if hasattr(item, 'to_dict') else item for item in result]
-            elif hasattr(result, 'to_dict'):
-                result_dict = result.to_dict()
-            else:
-                result_dict = result
-
-            debug_print(f"Result from get_application_configs: {result_dict}")
-            return result_dict
+            # Use raw JSON response to avoid Pydantic validation issues
+            result = api_client.get_application_configs_without_preload_content()
+            import json
+            try:
+                response_text = result.data.decode('utf-8')
+                json_data = json.loads(response_text)
+                # Convert to List[Dict[str, Any]] format
+                if isinstance(json_data, list):
+                    result_dict = json_data
+                else:
+                    # If it's a single object, wrap it in a list
+                    result_dict = [json_data] if json_data else []
+                debug_print("Successfully retrieved application configs data")
+                return result_dict
+            except (json.JSONDecodeError, AttributeError) as json_err:
+                error_message = f"Failed to parse JSON response: {json_err}"
+                debug_print(error_message)
+                return [{"error": error_message}]
 
         except Exception as e:
             debug_print(f"Error in get_application_configs: {e}")
             traceback.print_exc(file=sys.stderr)
             return [{"error": f"Failed to get all applications: {e!s}"}]
 
-    @register_as_tool
+    @register_as_tool(
+        title="Add Application Config",
+        annotations=ToolAnnotations(readOnlyHint=False, destructiveHint=False)
+    )
     @with_header_auth(ApplicationSettingsApi)
     async def add_application_config(self,
                                payload: Union[Dict[str, Any], str],
@@ -247,7 +263,10 @@ class ApplicationSettingsMCPTools(BaseInstanaClient):
             logger.error(f"Error in add_application_config: {e}")
             return {"error": f"Failed to add new application config: {e!s}"}
 
-    @register_as_tool
+    @register_as_tool(
+        title="Delete Application Config",
+        annotations=ToolAnnotations(readOnlyHint=False, destructiveHint=True)
+    )
     @with_header_auth(ApplicationSettingsApi)
     async def delete_application_config(self,
                                   id: str,
@@ -285,7 +304,10 @@ class ApplicationSettingsMCPTools(BaseInstanaClient):
             traceback.print_exc(file=sys.stderr)
             return {"error": f"Failed to delete application configuration: {e!s}"}
 
-    @register_as_tool
+    @register_as_tool(
+        title="Get Application Config",
+        annotations=ToolAnnotations(readOnlyHint=True, destructiveHint=False)
+    )
     @with_header_auth(ApplicationSettingsApi)
     async def get_application_config(self,
                                   id: str,
@@ -320,7 +342,10 @@ class ApplicationSettingsMCPTools(BaseInstanaClient):
             traceback.print_exc(file=sys.stderr)
             return {"error": f"Failed to get application configuration: {e!s}"}
 
-    @register_as_tool
+    @register_as_tool(
+        title="Update Application Config",
+        annotations=ToolAnnotations(readOnlyHint=False, destructiveHint=False)
+    )
     @with_header_auth(ApplicationSettingsApi)
     async def update_application_config(
         self,
@@ -473,7 +498,10 @@ class ApplicationSettingsMCPTools(BaseInstanaClient):
             logger.error(f"Error in put_application_config: {e}")
             return {"error": f"Failed to update existing application config: {e!s}"}
 
-    @register_as_tool
+    @register_as_tool(
+        title="Get All Endpoint Configs",
+        annotations=ToolAnnotations(readOnlyHint=True, destructiveHint=False)
+    )
     @with_header_auth(ApplicationSettingsApi)
     async def get_all_endpoint_configs(self,
                              ctx=None,
@@ -505,7 +533,10 @@ class ApplicationSettingsMCPTools(BaseInstanaClient):
             traceback.print_exc(file=sys.stderr)
             return [{"error": f"Failed to get endpoint configs: {e!s}"}]
 
-    @register_as_tool
+    @register_as_tool(
+        title="Create Endpoint Config",
+        annotations=ToolAnnotations(readOnlyHint=False, destructiveHint=False)
+    )
     @with_header_auth(ApplicationSettingsApi)
     async def create_endpoint_config(
         self,
@@ -607,7 +638,10 @@ class ApplicationSettingsMCPTools(BaseInstanaClient):
             logger.error(f"Error in create_endpoint_config: {e}")
             return {"error": f"Failed to create new endpoint config: {e!s}"}
 
-    @register_as_tool
+    @register_as_tool(
+        title="Delete Endpoint Config",
+        annotations=ToolAnnotations(readOnlyHint=False, destructiveHint=True)
+    )
     @with_header_auth(ApplicationSettingsApi)
     async def delete_endpoint_config(
         self,
@@ -645,7 +679,10 @@ class ApplicationSettingsMCPTools(BaseInstanaClient):
             traceback.print_exc(file=sys.stderr)
             return {"error": f"Failed to delete endpoint configs: {e!s}"}
 
-    @register_as_tool
+    @register_as_tool(
+        title="Get Endpoint Config",
+        annotations=ToolAnnotations(readOnlyHint=True, destructiveHint=False)
+    )
     @with_header_auth(ApplicationSettingsApi)
     async def get_endpoint_config(
         self,
@@ -685,7 +722,10 @@ class ApplicationSettingsMCPTools(BaseInstanaClient):
             traceback.print_exc(file=sys.stderr)
             return {"error": f"Failed to get endpoint configs: {e!s}"}
 
-    @register_as_tool
+    @register_as_tool(
+        title="Update Endpoint Config",
+        annotations=ToolAnnotations(readOnlyHint=False, destructiveHint=False)
+    )
     @with_header_auth(ApplicationSettingsApi)
     async def update_endpoint_config(
         self,
@@ -811,7 +851,10 @@ class ApplicationSettingsMCPTools(BaseInstanaClient):
             return {"error": f"Failed to update existing application config: {e!s}"}
 
 
-    @register_as_tool
+    @register_as_tool(
+        title="Get All Manual Service Configs",
+        annotations=ToolAnnotations(readOnlyHint=True, destructiveHint=False)
+    )
     @with_header_auth(ApplicationSettingsApi)
     async def get_all_manual_service_configs(self,
                              ctx=None,
@@ -843,7 +886,10 @@ class ApplicationSettingsMCPTools(BaseInstanaClient):
             traceback.print_exc(file=sys.stderr)
             return [{"error": f"Failed to get manual service configs: {e!s}"}]
 
-    @register_as_tool
+    @register_as_tool(
+        title="Add Manual Service Config",
+        annotations=ToolAnnotations(readOnlyHint=False, destructiveHint=False)
+    )
     @with_header_auth(ApplicationSettingsApi)
     async def add_manual_service_config(
         self,
@@ -960,7 +1006,10 @@ class ApplicationSettingsMCPTools(BaseInstanaClient):
             logger.error(f"Error in add_manual_service_config: {e}")
             return {"error": f"Failed to create new manual service config: {e!s}"}
 
-    @register_as_tool
+    @register_as_tool(
+        title="Delete Manual Service Config",
+        annotations=ToolAnnotations(readOnlyHint=False, destructiveHint=True)
+    )
     @with_header_auth(ApplicationSettingsApi)
     async def delete_manual_service_config(
         self,
@@ -998,7 +1047,10 @@ class ApplicationSettingsMCPTools(BaseInstanaClient):
             traceback.print_exc(file=sys.stderr)
             return {"error": f"Failed to delete manual service configs: {e!s}"}
 
-    @register_as_tool
+    @register_as_tool(
+        title="Update Manual Service Config",
+        annotations=ToolAnnotations(readOnlyHint=False, destructiveHint=False)
+    )
     @with_header_auth(ApplicationSettingsApi)
     async def update_manual_service_config(
         self,
@@ -1122,7 +1174,10 @@ class ApplicationSettingsMCPTools(BaseInstanaClient):
             return {"error": f"Failed to update manual config: {e!s}"}
 
 
-    @register_as_tool
+    @register_as_tool(
+        title="Replace All Manual Service Config",
+        annotations=ToolAnnotations(readOnlyHint=False, destructiveHint=True)
+    )
     @with_header_auth(ApplicationSettingsApi)
     async def replace_all_manual_service_config(
         self,
@@ -1244,7 +1299,10 @@ class ApplicationSettingsMCPTools(BaseInstanaClient):
             logger.error(f"Error in replace_all_manual_service_config: {e}")
             return [{"error": f"Failed to replace all manual config: {e!s}"}]
 
-    @register_as_tool
+    @register_as_tool(
+        title="Get All Service Configs",
+        annotations=ToolAnnotations(readOnlyHint=True, destructiveHint=False)
+    )
     @with_header_auth(ApplicationSettingsApi)
     async def get_all_service_configs(self,
                              ctx=None,
@@ -1276,7 +1334,10 @@ class ApplicationSettingsMCPTools(BaseInstanaClient):
             traceback.print_exc(file=sys.stderr)
             return [{"error": f"Failed to get application data metrics: {e}"}]
 
-    @register_as_tool
+    @register_as_tool(
+        title="Add Service Config",
+        annotations=ToolAnnotations(readOnlyHint=False, destructiveHint=False)
+    )
     @with_header_auth(ApplicationSettingsApi)
     async def add_service_config(self,
                             payload: Union[Dict[str, Any], str],
@@ -1388,7 +1449,10 @@ class ApplicationSettingsMCPTools(BaseInstanaClient):
             logger.error(f"Error in add_service_config: {e}")
             return {"error": f"Failed to add service config: {e!s}"}
 
-    @register_as_tool
+    @register_as_tool(
+        title="Replace All Service Configs",
+        annotations=ToolAnnotations(readOnlyHint=False, destructiveHint=True)
+    )
     @with_header_auth(ApplicationSettingsApi)
     async def replace_all_service_configs(self,
                             payload: Union[Dict[str, Any], str],
@@ -1498,7 +1562,10 @@ class ApplicationSettingsMCPTools(BaseInstanaClient):
             return [{"error": f"Failed to replace all service config: {e!s}"}]
 
 
-    @register_as_tool
+    @register_as_tool(
+        title="Order Service Config",
+        annotations=ToolAnnotations(readOnlyHint=False, destructiveHint=False)
+    )
     @with_header_auth(ApplicationSettingsApi)
     async def order_service_config(self,
                                    request_body: List[str],
@@ -1537,7 +1604,10 @@ class ApplicationSettingsMCPTools(BaseInstanaClient):
             traceback.print_exc(file=sys.stderr)
             return {"error": f"Failed to order service configs: {e!s}"}
 
-    @register_as_tool
+    @register_as_tool(
+        title="Delete Service Config",
+        annotations=ToolAnnotations(readOnlyHint=False, destructiveHint=True)
+    )
     @with_header_auth(ApplicationSettingsApi)
     async def delete_service_config(self,
                                 id: str,
@@ -1575,7 +1645,10 @@ class ApplicationSettingsMCPTools(BaseInstanaClient):
             traceback.print_exc(file=sys.stderr)
             return {"error": f"Failed to delete service configuration: {e!s}"}
 
-    @register_as_tool
+    @register_as_tool(
+        title="Get Service Config",
+        annotations=ToolAnnotations(readOnlyHint=True, destructiveHint=False)
+    )
     @with_header_auth(ApplicationSettingsApi)
     async def get_service_config(
         self,
@@ -1615,13 +1688,16 @@ class ApplicationSettingsMCPTools(BaseInstanaClient):
             traceback.print_exc(file=sys.stderr)
             return {"error": f"Failed to get service config: {e!s}"}
 
-    @register_as_tool
+    @register_as_tool(
+        title="Update Service Config",
+        annotations=ToolAnnotations(readOnlyHint=False, destructiveHint=False)
+    )
     @with_header_auth(ApplicationSettingsApi)
     async def update_service_config(self,
                             id: str,
                             payload: Union[Dict[str, Any], str],
                             ctx=None,
-                            api_client=None) -> Dict[str, Any]:
+                            api_client=None) -> Union[Dict[str, Any], List[Dict[str, Any]]]:
         """
         This tool gives is used if one wants to update a particular custom service rule.
         Args:
