@@ -25,6 +25,8 @@ except ImportError:
     logger.error("Failed to import infrastructure resources API", exc_info=True)
     raise
 
+from mcp.types import ToolAnnotations
+
 from src.core.utils import BaseInstanaClient, register_as_tool, with_header_auth
 
 # Configure logger for this module
@@ -37,7 +39,10 @@ class InfrastructureResourcesMCPTools(BaseInstanaClient):
         """Initialize the Infrastructure Resources MCP tools client."""
         super().__init__(read_token=read_token, base_url=base_url)
 
-    @register_as_tool
+    @register_as_tool(
+        title="Get Monitoring State",
+        annotations=ToolAnnotations(readOnlyHint=True, destructiveHint=False)
+    )
     @with_header_auth(InfrastructureResourcesApi)
     async def get_monitoring_state(self, ctx=None, api_client=None) -> Dict[str, Any]:
         """
@@ -63,7 +68,10 @@ class InfrastructureResourcesMCPTools(BaseInstanaClient):
             logger.error(f"Error in get_monitoring_state: {e}", exc_info=True)
             return {"error": f"Failed to get monitoring state: {e!s}"}
 
-    @register_as_tool
+    @register_as_tool(
+        title="Get Plugin Payload",
+        annotations=ToolAnnotations(readOnlyHint=True, destructiveHint=False)
+    )
     @with_header_auth(InfrastructureResourcesApi)
     async def get_plugin_payload(self,
                                  snapshot_id: str,
@@ -104,7 +112,10 @@ class InfrastructureResourcesMCPTools(BaseInstanaClient):
             logger.error(f"Error in get_plugin_payload: {e}", exc_info=True)
             return {"error": f"Failed to get plugin payload: {e!s}"}
 
-    @register_as_tool
+    @register_as_tool(
+        title="Get Snapshot",
+        annotations=ToolAnnotations(readOnlyHint=True, destructiveHint=False)
+    )
     @with_header_auth(InfrastructureResourcesApi)
     async def get_snapshot(self,
                            snapshot_id: str,
@@ -212,7 +223,10 @@ class InfrastructureResourcesMCPTools(BaseInstanaClient):
             logger.error(f"Error in get_snapshot: {e}", exc_info=True)
             return {"error": f"Failed to get snapshot: {e!s}"}
 
-    @register_as_tool
+    @register_as_tool(
+        title="Get Snapshots",
+        annotations=ToolAnnotations(readOnlyHint=True, destructiveHint=False)
+    )
     @with_header_auth(InfrastructureResourcesApi)
     async def get_snapshots(self,
                             query: Optional[str] = None,
@@ -367,7 +381,10 @@ class InfrastructureResourcesMCPTools(BaseInstanaClient):
 
 
 
-    @register_as_tool
+    @register_as_tool(
+        title="Post Snapshots",
+        annotations=ToolAnnotations(readOnlyHint=False, destructiveHint=False)
+    )
     @with_header_auth(InfrastructureResourcesApi)
     async def post_snapshots(self,
                              snapshot_ids: Union[List[str], str],
@@ -414,13 +431,12 @@ class InfrastructureResourcesMCPTools(BaseInstanaClient):
                 from instana_client.models.get_snapshots_query import (
                     GetSnapshotsQuery,  #type: ignore
                 )
+                from instana_client.models.time_frame import TimeFrame  #type: ignore
 
+                time_frame = TimeFrame(to=to_time, windowSize=window_size)
                 query_obj = GetSnapshotsQuery(
-                    snapshot_ids=snapshot_ids,
-                    time_frame={
-                        "to": to_time,
-                        "windowSize": window_size
-                    }
+                    snapshotIds=snapshot_ids if isinstance(snapshot_ids, list) else [snapshot_ids],
+                    timeFrame=time_frame
                 )
 
                 logger.debug("Making SDK request with without_preload_content...")
@@ -546,7 +562,10 @@ class InfrastructureResourcesMCPTools(BaseInstanaClient):
 
 
 
-    @register_as_tool
+    @register_as_tool(
+        title="Software Versions",
+        annotations=ToolAnnotations(readOnlyHint=True, destructiveHint=False)
+    )
     @with_header_auth(InfrastructureResourcesApi)
     async def software_versions(self, ctx=None, api_client=None) -> Dict[str, Any]:
         """
